<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Line</name>
    <message>
        <location filename="../Line.js" line="+81"/>
        <source>Line Tools</source>
        <translation>線分ツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show line tools</source>
        <translation>線分ツールを表示</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Line</source>
        <translation>&amp;L 線分</translation>
    </message>
    <message>
        <location filename="../Line.ui" line="+17"/>
        <source>Same Entity Type as Original</source>
        <translation>オリジナルと同じエンティティタイプ</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Line Segment</source>
        <translation>行</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Infinite Line</source>
        <translation>無限の線</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Ray</source>
        <translation>光線</translation>
    </message>
</context>
</TS>
